Index: content/browser/frame_host/navigator_impl.cc |
diff --git a/content/browser/frame_host/navigator_impl.cc b/content/browser/frame_host/navigator_impl.cc |
index 71063d8c46ba485a3eb2756f9ecb588f9f908940..5adba8d0796f05b27d99a1473f84b0e4f3a85b69 100644 |
--- a/content/browser/frame_host/navigator_impl.cc |
+++ b/content/browser/frame_host/navigator_impl.cc |
@@ -582,9 +582,11 @@ void NavigatorImpl::DidNavigate( |
params.insecure_request_policy); |
// Navigating to a new location means a new, fresh set of http headers and/or |
- // <meta> elements - we need to reset CSP policy to an empty set. |
- if (!is_navigation_within_page) |
+ // <meta> elements - we need to reset CSP and Feature Policy. |
+ if (!is_navigation_within_page) { |
render_frame_host->frame_tree_node()->ResetContentSecurityPolicy(); |
+ render_frame_host->frame_tree_node()->ResetFeaturePolicy(); |
+ } |
// When using --site-per-process, we notify the RFHM for all navigations, |
// not just main frame navigations. |